# 2048

![Downloads](https://img.shields.io/badge/Python-3776AB?style=for-the-badge&logo=python&logoColor=white)
![Downloads](https://img.shields.io/github/license/xXCoolinXx/2048.svg)
[![Downloads](https://static.pepy.tech/personalized-badge/py2048-coolin?period=total&units=international_system&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/py2048-coolin)

2048 Clone written in Python. <br>

To install, run `pip install py2048-coolin`. <br>
To execute, type `2048` and hit enter. If you haven't started the game before, it will download a font to your user data directory and make a `.json` save file there. <br>

Available on <a href="https://pypi.org/project/py2048-coolin/">PyPI</a>
